<?php
/**
 * Functions for displaying content
 *
 * @package xinmag
 * @since 1.0
 */
if ( ! function_exists( 'xinmag_top_menu' ) ):
function xinmag_top_menu() {
?>
<div id="topbar" class="contain-to-grid sticky-topbar">
<nav class="top-bar">
  <ul class="title-area">
	<li class="name">
<?php
	global $xinmag_options;

	if ( ! empty( $xinmag_options['brandname'] ) ) {
		echo '<h3><a href="' . esc_url( home_url() ) . '">';
		echo esc_attr( $xinmag_options['brandname'] ) . '</a></h3>';
	} elseif ( ! empty( $xinmag_options['brandlogo'] ) ) {
		echo '<a href="' . esc_url( home_url() ) . '"><img src="';
		echo esc_url( $xinmag_options['brandlogo'] ) . '" alt="';
		echo get_bloginfo( 'name' ) . '"></a>';
	}
?>
	</li>
	<li class="toggle-topbar menu-icon"><a href="#"><span>Menu</span></a></li>
  </ul>
  <section class="top-bar-section">
<?php
	if ( 'right' == $xinmag_options['menupos'] )
		add_filter('wp_nav_menu_items','xinmag_add_search_box', 10, 2);
	wp_nav_menu(array(
		'container' => false,
		'container_class' => 'menu',
		'menu_class' => 'top-bar-menu ' . $xinmag_options['menupos'],
		'theme_location' => 'top-bar', // where it's located in the theme
		'fallback_cb' => 'xinmag_nav_fb', // fallback function (see below)
		'walker' => new xinmag_topbar_walker()
	));
	if ( 'right' == $xinmag_options['menupos'] )
		remove_filter('wp_nav_menu_items','xinmag_add_search_box', 10, 2);
	else {
?>
	<section class="top-bar-section">
		<ul class="right">
			<li class="has-form"><?php get_search_form(); ?></li>
		</ul>
	</section>
<?php	
	}
?>
  </section>
</nav></div>
<?php
}
endif;

if ( ! function_exists( 'xinmag_logo_image' ) ) :
function xinmag_logo_image( $header_image, $size = 'full' ) {
	$html = '';
//	$header_image = get_header_image();
	if ( ! empty( $header_image ) ) {
		if( function_exists( 'get_custom_header' ) ) {
			$header_width = get_custom_header() -> width;
			$header_height = get_custom_header() -> height;
		}
		else {
			$header_width = HEADER_IMAGE_WIDTH;
			$header_height = HEADER_IMAGE_HEIGHT;				
		}
		if ( 'full' != $size ) {
			$ratio = $size / $header_height;
			$header_height = (int) $header_height * $ratio;
			$header_width = (int) $header_width  * $ratio;				 
		}
		$html = '<img src="' . $header_image . '" width="';
		$html .= $header_width . '" height="' . $header_height;
		$html .= '" alt="' . get_bloginfo( 'name') . '" />';
	}	
	echo apply_filters( 'xinmag_logo_image', $html );
}
endif;

if  ( ! function_exists( 'xinmag_branding' ) ) :
function xinmag_branding() {
?>
<div id="branding" class="large-12 columns">
<?php
	xinmag_header_branding(); //Action Hooks
	get_sidebar( 'header' );
	$header_image = get_header_image();
	if ( ! empty( $header_image ) ) { ?>
		<div id="logo" class="left">
          <a href="<?php echo esc_url( home_url( '/' ) ); ?>">
		  	<?php xinmag_logo_image( $header_image ) ?>
		  </a>
		</div>
<?php
	} else { ?>
	<div class="site-title">
		<h3 id="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h3>
		<h3 id="site-description"><?php bloginfo( 'description' ); ?></h3>
	</div>
<?php } ?>
</div>
<?php
}
endif;

if ( ! function_exists( 'xinmag_post_title' ) ) :
// Display Post Title
function xinmag_post_title() {
	global $xinmag_layout;
	if ( ! is_single()  ) {
		printf('<h2 class="entry-title"><a href="%1$s" title="%2$s" rel="bookmark">%3$s</a></h2>',
			get_permalink(),
			sprintf( esc_attr__( 'Permalink to %s', 'xinmag' ), the_title_attribute( 'echo=0' ) ),
			get_the_title()	);
	}
	elseif ( 2 == $xinmag_layout ) {
		printf('<h1 class="entry-title">%1$s</h1>',
			get_the_title()	);		
	}
}
endif;

if ( ! function_exists( 'xinmag_title_bar' ) ) :	
function xinmag_title_bar() { ?>
	<div id="title" class="titlebar">
<?php
	if ( ! is_home() || function_exists( 'bcn_display' ) ) {
?>
	  <div class="row">
		<div class="large-12 columns">
<?php		xinmag_page_title(); ?>
<?php	if ( function_exists( 'bcn_display' ) ) { ?>
		<div class="breadcrumbs">	
<?php        bcn_display(); ?>
		</div>
<?php 	} ?>
	  	</div>
	  </div>	  
<?php } ?>
	</div>
<?php
}
endif;

if ( ! function_exists( 'xinmag_page_title' ) ) :	
function xinmag_page_title() {
	global $xinmag_options, $post;
	if ( ! have_posts()) return;
	if ( is_single() ) {
		printf( '<h1>%1$s</h1>', get_the_title() );	
	} elseif ( is_page() ) {
		$pagetitle = get_post_meta( $post->ID, '_xinmag_title', true );
		
		if ( empty( $pagetitle ) )
			printf( '<h1>%1$s</h1>', get_the_title() );
	} elseif ( is_search() ) { ?>
		<h1><?php printf( __( 'Search Results for: %s', 'xinmag' ), '<span>' . get_search_query() . '</span>' ); ?></h1>	
<?php
	} elseif ( is_author() ) {
			the_post(); ?>
			<h1><?php printf( __( 'Author Archives: %s', 'xinmag' ), '<a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( "ID" ) ) ) . '" title="' . esc_attr( get_the_author() ) . '" rel="me">' . get_the_author() . '</a>' ); ?></h1>
<?php		rewind_posts();		
		
	}
	elseif ( is_category() ) {
		$category_description = category_description();
		if ( empty( $category_description ) ) { ?>					
			<h1><?php printf( __( 'Category Archives: %s', 'xinmag' ), '<span>' . single_cat_title( '', false ) . '</span>' ); ?></h1>
<?php
		} else
			echo '<h1>'. $category_description .'</h1>';			
	}
	elseif ( is_tag() ) {
		$tag_description = tag_description();
		if ( empty( $tag_description ) ) { ?>					
			<h1><?php printf( __( 'Tag Archives: %s', 'xinmag' ), '<span>' . single_tag_title( '', false ) . '</span>' ); ?></h1>
<?php
		} else
			echo '<h1>'. $tag_description .'</h1>';			
	}
	elseif ( is_archive() ) {
		echo '<h1>';
		if ( is_day() ) 
			printf( __( 'Daily Archives: %s', 'xinmag' ), '<span>' . get_the_date() . '</span>' );
		elseif ( is_month() )
			printf( __( 'Monthly Archives: %s', 'xinmag' ), '<span>' . get_the_date( _x( 'F Y', 'monthly archives date format', 'xinmag' ) ) . '</span>' );
		elseif ( is_year() )
			printf( __( 'Yearly Archives: %s', 'xinmag' ), '<span>' . get_the_date( _x( 'Y', 'yearly archives date format', 'xinmag' ) ) . '</span>' );
		else
			the_title(); 
		echo '</h1>';	
	}
}
endif;

if ( ! function_exists( 'xinmag_single_post_link' ) ) :
/* This function echo the link to single post view for the following:
- Aside Post
- Post without title
------------------------------------------------------------------------- */
function xinmag_single_post_link() {
	if ( ! is_single() ) {
		if ( has_post_format( 'aside' ) || has_post_format( 'quote' ) || '' == the_title_attribute( 'echo=0' ) ) { 
			printf ('<a class="single-post-link" href="%1$s" title="%1$s"><i class="icon-chevron-right"></i></a>',
				get_permalink(),
				get_the_title()	);
		} 
	}
}
endif;

if ( ! function_exists( 'xinmag_display_post_thumbnail' ) ) :
// Display Large Post Thumbnail on top of the post
function xinmag_display_post_thumbnail( $post_id ) {
	global $xinmag_layout;
	if ( has_post_thumbnail() ) {
		if ( ! is_single() ) {
			printf ('<a href="%1$s" title="%2$s">', 
				get_permalink(),
				get_the_title()	);	
			the_post_thumbnail( 'large', array( 'class'	=> 'img-polaroid featured-image', 'title' => get_the_title() ) );
			echo '</a>';
		}
		else {
			if ( 2 == $xinmag_layout )			
				the_post_thumbnail( 'full', array( 'class'	=> 'fullscreen-image' ) );	
			else
				the_post_thumbnail( 'large', array( 'class'	=> 'img-polaroid featured-image', 'title' => get_the_title() ) );	
		}
	}
}
endif;

if ( ! function_exists( 'xinmag_template_intro' ) ) :
function xinmag_template_intro() {
	global $post, $xinmag_options;
		
//	$pagetitle = get_post_meta( $post->ID, '_xinmag_title', true );
	$content = get_the_content();
	$content = apply_filters( 'the_content', $content );
	$content = str_replace( ']]>', ']]&gt;', $content );
	if ( ! empty($content)) {
?>
<article id="post-<?php the_ID(); ?>" class="template-intro clearfix <?php echo xinmag_grid_full(); ?>">
<?php
		echo '<div class="entry-content clearfix">';
		echo $content;
		echo '</div>';			
?>
</article>
<?php
	}
}
endif;