<?php
/**
 * Functions for Foundation Framework
 *
 * @package xinmag
 * @since 1.0
 */
class xinmag_topbar_walker extends Walker_Nav_Menu {
 
	function display_element( $element, &$children_elements, $max_depth, $depth=0, $args, &$output ) {
		$element->has_children = ! empty( $children_elements[ $element->ID ] );
		$element->classes[] = ( $element->current || $element->current_item_ancestor) ? 'active' : '';
		$element->classes[] = ( $element->has_children ) ? 'has-dropdown' : '';
		parent::display_element( $element, $children_elements, $max_depth, $depth, $args, $output );
	}

	function start_el( &$output, $item, $depth, $args ) {
		$item_html = '';
		parent::start_el( $item_html, $item, $depth, $args );	
		$output .= ( 0 == $depth) ? '<li class="divider"></li>' : '';
		$classes = empty( $item->classes ) ? array() : (array) $item->classes;	
		if( in_array( 'section', $classes ) ) {
			$output .= '<li class="divider"></li>';
			$item_html = preg_replace('/<a[^>]*>(.*)<\/a>/iU', '<label>$1</label>', $item_html);
		}
		$output .= $item_html;
	}

	function start_lvl(&$output, $depth = 0, $args = array() ) {
		$output .= "\n<ul class=\"sub-menu dropdown\">\n";
	}
}

function xinmag_nav_fb() {
	echo '<ul class="nav-bar">';
	wp_list_pages(array(
			'echo' => 1,
			'title_li'     => '',
			'sort_column' => 'menu_order, post_title',
			'walker' => new xinmag_page_walker(),
			'post_type' => 'page',
			'post_status' => 'publish'
	));
	echo '</ul>';
}

class xinmag_page_walker extends Walker_Page {
	
	function start_el( &$output, $page, $depth, $args, $current_page ) {
		$item_html = '';
		parent::start_el( $item_html, $page, $depth, $args, $current_page );
		$css_class = array( 'page_item', 'page-item-'.$page->ID );
		if ( $args['has_children'] ) {
			$css_class[] = 'has-dropdown';
		}
		$css_class = implode( ' ', apply_filters( 'page_css_class', $css_class, $page, $depth, $args, $current_page ) );
		$item_html = '<li class="' . $css_class . '"><a href="' . get_permalink($page->ID) . '">' . apply_filters( 'the_title', $page->post_title, $page->ID ) . '</a>';
		$output .= $item_html;
	}
 
	function start_lvl( &$output, $depth = 0, $args = array() ) {
		$output .= "\n<ul class=\"dropdown\">\n";
	}
}

if ( ! function_exists( 'xinmag_content_class' ) ) :
function xinmag_content_class() {
    global $xinmag_options;
	$class = "large-" . $xinmag_options['content'] . ' ' ;
	if ( 2 == $xinmag_options['sidebarpos'] && ( $xinmag_options['sidebar1'] > 0 || $xinmag_options['sidebar2'] > 0 ) ) {
		if ( ( $xinmag_options['content'] + $xinmag_options['sidebar1'] + $xinmag_options['sidebar2'] ) > 12 ) {
			if ($xinmag_options['sidebar1'] > $xinmag_options['sidebar2'])
				$push_col = $xinmag_options['sidebar1']; 
			else
				$push_col = $xinmag_options['sidebar2'];
		}
		else {
			$push_col = $xinmag_options['sidebar1'] + $xinmag_options['sidebar2']; 			
		}
		$class = $class . "push-" . $push_col . ' ';
	}
	elseif ( 3 == $xinmag_options['sidebarpos'] && $xinmag_options['sidebar1'] > 0 ) {
		$push_col = $xinmag_options['sidebar1']; 
		$class = $class . "push-" . $push_col . ' ';		
	}
	$class .= 'columns';
	return $class;
}
endif;

if ( ! function_exists( 'xinmag_grid_columns' ) ) :
function xinmag_grid_columns( $col ) {
	return 'large-' . $col . ' columns';
}
endif; 

if ( ! function_exists( 'xinmag_grid_full' ) ) :
function xinmag_grid_full() {
	return "large-12 columns";
}
endif;

if ( ! function_exists( 'xinmag_bbp_class' ) ) :
/** return grid class for bbPress & BuddyPress page */
function xinmag_bbp_class() {
    global $xinmag_options;

	$class = "large-" . $xinmag_options['bbp_column1'] . ' columns ' ;
	if ( 1 == $xinmag_options['bbp_position'] && $xinmag_options['bbp_column2'] > 0 ) {
			$push_col = $xinmag_options['bbp_column2']; 	
		$class = $class . "push-" . $push_col . ' ';
	}
	$class = $class . 'bbp-content';
	return $class;
}
endif;

function xinmag_add_search_box($items, $args) {
	ob_start();
    get_search_form();
	$searchform = ob_get_contents();
	ob_end_clean();

	$items .= '<li class="has-form">' . $searchform . '</li>';
    return $items;
}