<?php
if ( ! defined( 'ABSPATH' ) ) exit;
/**
 * General Framework function
 *
 * @package xinmag
 * @since 1.0
 */
function xinmag_wp_title( $title, $sep ) {
	global $paged, $page;

	if ( is_feed() )
		return $title;

	$title .= get_bloginfo( 'name' );
	
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title = "$title $sep $site_description";
	if ( $paged >= 2 || $page >= 2 )
		$title = "$title $sep " . sprintf( __( 'Page %s', 'xinmag' ), max( $paged, $page ) );

	return $title;
}
add_filter( 'wp_title', 'xinmag_wp_title', 10, 2 );

function xinmag_thumbnail_array() {
	$sizes = array (
		array(	'key' => '',
				'name' => __( 'Thumbnail', 'xinmag' ) ),
		array(	'key' => 'medium',
				'name' => __( 'Medium', 'xinmag' ) ),
		array(	'key' => 'large',
				'name' => __( 'Large', 'xinmag' ) ),
		array(	'key' => 'full',
				'name' => __( 'Full', 'xinmag' ) ),
		array(	'key' => 'custom',
				'name' => __( 'Custom', 'xinmag' ) ),
		array(	'key' => 'none',
				'name' => __( 'None', 'xinmag' ) ),
	);
	global $_wp_additional_image_sizes;

	if ( isset( $_wp_additional_image_sizes ) )
		foreach( $_wp_additional_image_sizes as $name => $item) 
			$sizes[] = array( 'key' => $name, 'name' => $name );
	return apply_filters( 'xinmag_thumbnail_array', $sizes );
}

function xinmag_post_types() { 
	$args = array(
  		'public'   => true,
  		'_builtin' => false ); 
	$post_types = get_post_types( $args ); 
	$types = array( 
		array(	'key' => 'post',
				'name' => __( 'post', 'xinmag' ) ),
		array(	'key' => 'page',
				'name' => __( 'page', 'xinmag' ) ),
	);
	foreach ( $post_types as $post_type ) {
		$types[] = array( 'key' => $post_type, 'name' => $post_type );
	}
	return apply_filters( 'xinmag_post_types', $types );
}

function xinmag_gallery_image_ids( $content ) {
	$image_ids = array();
    preg_match_all( '/\[gallery.*.\]/' , $content, $matches);
	foreach ( $matches[0] as $match ) {
        $str = str_replace (" ", "&", trim ($match));
        $str = str_replace ('"', '', $str);
		$attrs = wp_parse_args( $str );
		if ( isset( $attrs['ids'] ) ) {
			$ids = explode( ',', $attrs['ids'] );	
			$image_ids = array_merge( $image_ids, $ids );	
		}
	}
	return $image_ids;
}

function xinmag_skitter_content( $images, $size = 'full' ) {
	$slider = '<div class="border_box">';
	$slider .= '<div class="box_skitter box_skitter_inline box_skitter_custom">';
	$slider .= '<ul>';
	foreach ( $images as $id ) {
		$slider .= '<li>';
		$image = wp_get_attachment_image_src( $id, $size );
		$slider .=  '<img src="' . $image[0] . '" class="random">';
		$alt_text = get_post_meta($id, '_wp_attachment_image_alt', true);
		$slider .=  '<div class="label_text"><p>' .  $alt_text . '</p></div>';
		$slider .=  '</li>';		
	}
	$slider .= '</ul></div></div>';
	return apply_filters( 'xinmag_skitter_content', $slider );
}

function xinmag_skitter_inline( $images, $size = 'full' ) {
	$height = 99999;

	foreach ( $images as $id ) {
		$image = wp_get_attachment_image_src( $id, $size );
		if ( $image[2] < $height )
			$height = $image[2];
	}
	$css = "<!-- xinmag Skitter Inline CSS -->\n";
	$css .= "<style>\n";
	$css .= '.box_skitter_inline {' . "\n";
	$css .= '  height: ' . $height . 'px;' . "\n";
	$css .= "}\n";
	$css .= "</style>\n<!-- xinmag Skitter Inline CSS -->\n";
	echo apply_filters( 'xinmag_skitter_inline', $css );
}
//Sorting array by key
function xinmag_sort_array( &$array, $key ) {
    $sorter = array();
    $ret = array();
    reset( $array );
    foreach ( $array as $ii => $va ) {
        $sorter[ $ii ] = $va[ $key ];
    }
    asort( $sorter );
    foreach ( $sorter as $ii => $va ) {
        $ret[ $ii ] = $array[ $ii ];
    }
    $array = $ret;
}
/* Category Array */
function xinmag_categories() {
	$category = get_categories();
	return apply_filters( 'xinmag_categories', $category );
}	
/* Content Filter: Remove image from post*/
function xinmag_remove_images( $content ) {
   $postOutput = preg_replace('/<img[^>]+./','', $content);
   return $postOutput;
}
